---
title: <span class="badge object-type-scalar"></span> WattHourPerKilogram
---
# <span class="badge object-type-scalar"></span> WattHourPerKilogram

Energy: Watt-hour per Kilogram (Wh/kg)

## Definition

```python
# Energy: Watt-hour per Kilogram (Wh/kg)
WattHourPerKilogram: typing.Literal["watthperkg"] = "watthperkg"
```
